@@ -30,14 +30,6 @@
 
 #undef DEBUG_PUSH_POP
 
-/* Dead kittens.  */
-#ifndef HAVE_G_VALUE_SET_SCHAR
-#define g_value_set_schar(v_,sc_) g_value_set_char((v_),(char)(sc_))
-#endif
-#ifndef HAVE_G_VALUE_GET_SCHAR
-#define g_value_get_schar(v_) (signed char)g_value_get_char((v_))
-#endif
-
 static GObjectClass *parent_class;
 
 static gint
@@ -363,10 +355,11 @@ gsf_xml_parser_context (GsfInput *input)
 /**
  * gsf_xml_output_buffer_new: (skip)
  * @output: #GsfOutput
- * @handler (allow-none):
+ * @handler: (allow-none) (scope call):
  *
  * <note>This adds a reference to @output.</note>
  * <note>This is <emphasis>not</emphasis> releated to #GsfXMLOut.</note>
+ * Hmm... @handler.
  **/
 static xmlOutputBufferPtr
 gsf_xml_output_buffer_new (GsfOutput *output,
@@ -547,7 +540,7 @@ gsf_xml_probe (GsfInput *input, GsfXMLProbeFunc func)
  * GsfXMLIn:
  * @user_state: user data
  * @content: the current node content
- * @doc: #GsfXMLInDoc
+ * @doc: Current document being parsed #GsfXMLInDoc
  * @node: current node (not on the stack)
  **/
 
@@ -1094,7 +1087,7 @@ gsf_xml_in_node_internal_free (GsfXMLInNodeInternal *node)
 
 /**
  * gsf_xml_in_doc_free:
- * @doc: #GsfXMLInDoc
+ * @doc: A #GsfXMLInDoc
  *
  * Free up resources
  **/
@@ -1487,6 +1480,9 @@ typedef struct _GsfXMLOutPrivate {
 	gboolean	  pretty_print;
 } GsfXMLOutPrivate;
 
+G_DEFINE_TYPE_WITH_CODE (GsfXMLOut, gsf_xml_out, G_TYPE_OBJECT,
+			 G_ADD_PRIVATE (GsfXMLOut))
+
 static void
 gsf_xml_out_set_output (GsfXMLOut *xout, GsfOutput *output)
 {
@@ -1547,11 +1543,10 @@ gsf_xml_out_finalize (GObject *obj)
 }
 
 static void
-gsf_xml_out_init (GObject *obj)
+gsf_xml_out_init (GsfXMLOut *xout)
 {
-	GsfXMLOut *xout = GSF_XML_OUT (obj);
-	GsfXMLOutPrivate *priv = G_TYPE_INSTANCE_GET_PRIVATE
-		(obj, GSF_XML_OUT_TYPE, GsfXMLOutPrivate);
+	GsfXMLOutPrivate *priv = gsf_xml_out_get_instance_private (xout);
+
 	xout->output = NULL;
 	xout->priv = priv;
 	priv->stack  = NULL;
@@ -1563,8 +1558,10 @@ gsf_xml_out_init (GObject *obj)
 }
 
 static void
-gsf_xml_out_class_init (GObjectClass *gobject_class)
+gsf_xml_out_class_init (GsfXMLOutClass *klass)
 {
+	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+
 	parent_class = g_type_class_peek_parent (gobject_class);
 
 	gobject_class->finalize	    = gsf_xml_out_finalize;
@@ -1576,7 +1573,7 @@ gsf_xml_out_class_init (GObjectClass *gobject_class)
 		 g_param_spec_boolean ("pretty-print",
 				       _("Pretty print"),
 				       _("Should the output auto-indent elements to make reading easier?"),
-			TRUE, GSF_PARAM_STATIC | G_PARAM_READWRITE));
+			TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE));
 
 	g_object_class_install_property
 		(gobject_class, PROP_SINK,
@@ -1584,17 +1581,11 @@ gsf_xml_out_class_init (GObjectClass *gobject_class)
 				      _("Sink"),
 				      _("The destination for writes"),
 				      GSF_OUTPUT_TYPE,
-				      GSF_PARAM_STATIC |
+				      G_PARAM_STATIC_STRINGS |
 				      G_PARAM_READWRITE |
 				      G_PARAM_CONSTRUCT_ONLY));
-
-	g_type_class_add_private (gobject_class, sizeof (GsfXMLOutPrivate));
 }
 
-GSF_CLASS (GsfXMLOut, gsf_xml_out,
-	   gsf_xml_out_class_init, gsf_xml_out_init,
-	   G_TYPE_OBJECT)
-
 /**
  * gsf_xml_out_new:
  * @output: #GsfOutput
