@@ -463,12 +463,16 @@ gsf_open_pkg_parse_rel_by_id (GsfXMLIn *xin, char const *id,
 /* DEPRECATED in 1.14.6 */
 /**
  * gsf_open_pkg_get_rel_by_type: (skip)
+ * @opkg:
+ * @type:
  *
  * Deprecated: 1.14.6
  */
 GsfInput *gsf_open_pkg_get_rel_by_type (GsfInput *opkg, char const *type) { return gsf_open_pkg_open_rel_by_type (opkg, type, NULL); }
 /**
  * gsf_open_pkg_get_rel_by_id: (skip)
+ * @opkg:
+ * @id:
  *
  * Deprecated: 1.14.6
  */
@@ -769,21 +773,21 @@ gsf_outfile_open_pkg_class_init (GObjectClass *gobject_class)
 				      _("Sink"),
 				      _("The GsfOutput that stores the Open Package content"),
 				      GSF_OUTFILE_TYPE,
-				      GSF_PARAM_STATIC | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+				      G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
 	g_object_class_install_property (gobject_class, PROP_CONTENT_TYPE,
 		 g_param_spec_string ("content-type",
 				      _("Content type"),
 				      _("The content type stored in the root [Content_Types].xml file"),
 				      "",
-				      GSF_PARAM_STATIC | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+				      G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
 	g_object_class_install_property (gobject_class, PROP_IS_DIR,
 		 g_param_spec_boolean ("is-dir",
 				       _("Is Directory"),
 				       _("Can the outfile have children"),
 				       FALSE,
-				       GSF_PARAM_STATIC | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+				       G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 GSF_CLASS (GsfOutfileOpenPkg, gsf_outfile_open_pkg,
